==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PlatformConditionEvaluatorPlatformOperatingSystem.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionEvaluatorPlatformOperatingSystemVersion;
import com.okta.sdk.resource.model.PolicyPlatformOperatingSystemType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformConditionEvaluatorPlatformOperatingSystem
 */
@JsonPropertyOrder({ PlatformConditionEvaluatorPlatformOperatingSystem.JSON_PROPERTY_EXPRESSION,
        PlatformConditionEvaluatorPlatformOperatingSystem.JSON_PROPERTY_TYPE,
        PlatformConditionEvaluatorPlatformOperatingSystem.JSON_PROPERTY_VERSION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PlatformConditionEvaluatorPlatformOperatingSystem implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXPRESSION = "expression";
    private String expression;

    public static final String JSON_PROPERTY_TYPE = "type";
    private PolicyPlatformOperatingSystemType type;

    public static final String JSON_PROPERTY_VERSION = "version";
    private PlatformConditionEvaluatorPlatformOperatingSystemVersion version;

    public PlatformConditionEvaluatorPlatformOperatingSystem() {
    }

    public PlatformConditionEvaluatorPlatformOperatingSystem expression(String expression) {

        this.expression = expression;
        return this;
    }

    /**
     * Get expression
     *
     * @return expression
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getExpression() {
        return expression;
    }

    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExpression(String expression) {
        this.expression = expression;
    }

    public PlatformConditionEvaluatorPlatformOperatingSystem type(PolicyPlatformOperatingSystemType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyPlatformOperatingSystemType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(PolicyPlatformOperatingSystemType type) {
        this.type = type;
    }

    public PlatformConditionEvaluatorPlatformOperatingSystem version(
            PlatformConditionEvaluatorPlatformOperatingSystemVersion version) {

        this.version = version;
        return this;
    }

    /**
     * Get version
     *
     * @return version
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion getVersion() {
        return version;
    }

    @JsonProperty(JSON_PROPERTY_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVersion(PlatformConditionEvaluatorPlatformOperatingSystemVersion version) {
        this.version = version;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformConditionEvaluatorPlatformOperatingSystem platformConditionEvaluatorPlatformOperatingSystem = (PlatformConditionEvaluatorPlatformOperatingSystem) o;
        return Objects.equals(this.expression, platformConditionEvaluatorPlatformOperatingSystem.expression)
                && Objects.equals(this.type, platformConditionEvaluatorPlatformOperatingSystem.type)
                && Objects.equals(this.version, platformConditionEvaluatorPlatformOperatingSystem.version);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(expression, type, version);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformConditionEvaluatorPlatformOperatingSystem {\n");
        sb.append("    expression: ").append(toIndentedString(expression)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    version: ").append(toIndentedString(version)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PlatformConditionEvaluatorPlatformOperatingSystem.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionEvaluatorPlatformOperatingSystemVersion;
import com.okta.sdk.resource.model.PolicyPlatformOperatingSystemType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformConditionEvaluatorPlatformOperatingSystem
 */
@JsonPropertyOrder({ PlatformConditionEvaluatorPlatformOperatingSystem.JSON_PROPERTY_EXPRESSION,
        PlatformConditionEvaluatorPlatformOperatingSystem.JSON_PROPERTY_TYPE,
        PlatformConditionEvaluatorPlatformOperatingSystem.JSON_PROPERTY_VERSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PlatformConditionEvaluatorPlatformOperatingSystem implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXPRESSION = "expression";
    private String expression;

    public static final String JSON_PROPERTY_TYPE = "type";
    private PolicyPlatformOperatingSystemType type;

    public static final String JSON_PROPERTY_VERSION = "version";
    private PlatformConditionEvaluatorPlatformOperatingSystemVersion version;

    public PlatformConditionEvaluatorPlatformOperatingSystem() {
    }

    public PlatformConditionEvaluatorPlatformOperatingSystem expression(String expression) {

        this.expression = expression;
        return this;
    }

    /**
     * Get expression
     *
     * @return expression
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getExpression() {
        return expression;
    }

    @JsonProperty(JSON_PROPERTY_EXPRESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExpression(String expression) {
        this.expression = expression;
    }

    public PlatformConditionEvaluatorPlatformOperatingSystem type(PolicyPlatformOperatingSystemType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyPlatformOperatingSystemType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(PolicyPlatformOperatingSystemType type) {
        this.type = type;
    }

    public PlatformConditionEvaluatorPlatformOperatingSystem version(
            PlatformConditionEvaluatorPlatformOperatingSystemVersion version) {

        this.version = version;
        return this;
    }

    /**
     * Get version
     *
     * @return version
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion getVersion() {
        return version;
    }

    @JsonProperty(JSON_PROPERTY_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVersion(PlatformConditionEvaluatorPlatformOperatingSystemVersion version) {
        this.version = version;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformConditionEvaluatorPlatformOperatingSystem platformConditionEvaluatorPlatformOperatingSystem = (PlatformConditionEvaluatorPlatformOperatingSystem) o;
        return Objects.equals(this.expression, platformConditionEvaluatorPlatformOperatingSystem.expression)
                && Objects.equals(this.type, platformConditionEvaluatorPlatformOperatingSystem.type)
                && Objects.equals(this.version, platformConditionEvaluatorPlatformOperatingSystem.version);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(expression, type, version);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformConditionEvaluatorPlatformOperatingSystem {\n");
        sb.append("    expression: ").append(toIndentedString(expression)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    version: ").append(toIndentedString(version)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
